@@ -1,13 +1,13 @@
-# $Id: Ingredient.pm 990 2005-09-23 20:13:56Z btrott $
+# $Id$
 
 package Ingredient;
 use strict;
 use base qw( Data::ObjectDriver::BaseObject );
+use DodTestUtil;
 
 use Carp ();
 use Data::ObjectDriver::Driver::DBI;
-use Data::ObjectDriver::Driver::Cache::Cache;
-use Cache::Memory;
+use Data::ObjectDriver::Driver::Cache::RAM;
 
 our %IDs;
 
@@ -15,11 +15,11 @@ __PACKAGE__->install_properties({
     columns => [ 'id', 'recipe_id', 'name', 'quantity' ],
     datasource => 'ingredients',
     primary_key => [ 'recipe_id', 'id' ],
-    driver      => Data::ObjectDriver::Driver::Cache::Cache->new(
-        cache => Cache::Memory->new,
+    driver      => Data::ObjectDriver::Driver::Cache::RAM->new(
         fallback => Data::ObjectDriver::Driver::DBI->new(
-            dsn      => 'dbi:SQLite:dbname=global.db',
+            dsn      => DodTestUtil::dsn('global'),
             pk_generator => \&generate_pk,
+            reuse_dbh => 1,
         ),
         pk_generator => \&generate_pk,
     ),
